16.46. cdist-type__dog_vdi(7) — cdist 6.9.4 documentation

# 16.46. cdist-type__dog_vdi(7)

## 16.46.1. NAME

cdist-type__dog_vdi - Manage Sheepdog VM images

## 16.46.2. DESCRIPTION

The dog program is used to create images for sheepdog to be used in qemu.

## 16.46.3. OPTIONAL PARAMETERS

state

  Either "present" or "absent", defaults to "present"

size

  Size of the image in "dog vdi" compatible units.

  Required if state is "present".

## 16.46.4. EXAMPLES

    # Create a 50G size image
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G

    # Create a 50G size image (more explicit)
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G --state present

    # Remove image
    __dog_vdi nico-privat.sky.ungleich.ch --state absent

    # Remove image - keeping --size is ok
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G --state absent

## 16.46.5. SEE ALSO

qemu(1), dog(8)

## 16.46.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.46.7. COPYING

Copyright (C) 2014 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.